import { RemovalPolicy } from 'aws-cdk-lib';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import { Construct } from 'constructs';
/**
 * Properties to initialize an instance of `MicroAppsAppNextjsDemo`.
 *
 * @stability stable
 */
export interface MicroAppsAppNextjsDemoProps {
    /**
     * Name for the Lambda function.
     *
     * While this can be random, it's much easier to make it deterministic
     * so it can be computed for passing to `microapps-publish`.
     *
     * @default auto-generated
     * @stability stable
     */
    readonly functionName?: string;
    /**
     * Removal Policy to pass to assets (e.g. Lambda function).
     *
     * @stability stable
     */
    readonly removalPolicy?: RemovalPolicy;
    /**
     * NODE_ENV to set on Lambda.
     *
     * @stability stable
     */
    readonly nodeEnv?: 'dev' | 'qa' | 'prod';
}
/**
 * Represents an app.
 *
 * @stability stable
 */
export interface IMicroAppsAppNextjsDemo {
    /**
     * The Lambda function created.
     *
     * @stability stable
     */
    readonly lambdaFunction: lambda.IFunction;
}
/**
 * MicroApps Next.js demo app.
 *
 * @stability stable
 */
export declare class MicroAppsAppNextjsDemo extends Construct implements IMicroAppsAppNextjsDemo {
    private _lambdaFunction;
    /**
     * The Lambda function created.
     *
     * @stability stable
     */
    get lambdaFunction(): lambda.IFunction;
    /**
     * Lambda function, permissions, and assets used by the app.
     *
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: MicroAppsAppNextjsDemoProps);
}
